===============================
 reno -- Release Notes Manager
===============================

Reno is a release notes manager for storing release notes in a git
repository and then building documentation from them.

Project Meta-data
=================

* Free software: Apache license
* Documentation: http://docs.openstack.org/developer/reno
* Source: http://git.openstack.org/cgit/openstack/reno
* Bugs: http://bugs.launchpad.net/reno

Features
========

* TODO
